.. _step_custom:

Custom Layer
============

The custom parameters module allows users to define their own parameters dynamically. This is useful when a predefined parameter set does not fit a specific use case.

In the configuration file, you can pass any parameter that you need to use in the custom algorithm. The only parameter that is already defined is `raise_error`, which is a boolean that determines whether an error should be raised if an issue occurs.

More details on working with custom algorithms, please refer to the :ref:`guide_custom_algorithms` documentation.
